R/sample_partition_correlation.R
sample_partition_correlation.RdThis function implements a reversible jump MCMC procedure for updating the parameter partition in Bayesian Rank-Clustered Estimation for Network Meta-Analysis models in the case when we assume correlation among treatment effects. For internal use only.
sample_partition_correlation(
mu_hat,
J,
nu,
g,
K,
mu0,
sigma0,
cov,
tau = tau,
b_g = 0.5,
d_g = 0.5,
logdmvn = NULL
)A vector of estimated average relative intervention effects based on a previous NMA. The jth entry is the effect of intervention j.
A numeric indicating the total number of interventions being compared.
A vector indicating current values for nu in the Gibbs sampler.
A vector indicating current values for g in the Gibbs sampler.
A vector indicating current values for K in the Gibbs sampler.
The hyperparameter mu0, usually specified as the grand mean of the average intervention effects.
The hyperparameter sigma_0, usually a large number as to be minimally informative.
A variance covariance matrix of relative intervention effects based on a previous NMA. The (i,j) entry is the covariane between intervention i and j's effects.
The standard deviation of the Metropolis Hastings proposal distribution.
The probability of "birth"ing a new partition cluster, if possible. Default is 0.5.
The probability of "death"ing an existing partition cluster, if possible. Default is 0.5.
An optional function of (x, mean) returning the multivariate normal log-density with covariance cov, as built by make_logdmvnorm. Supplying it avoids re-factorising cov on every call. If NULL, one is built from cov.
A list containing updated values for g, nu, and K.