This function creates trace plots for the K parameter in the form of a ggplot.

traceplot_K(mcmc)

Arguments

mcmc

MCMC draws from the RaCE NMA model, in the form of the model output of the mcmc_raceNMA function.

Value

A ggplot of trace plots for the K parameter.

Examples

mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
#> Estimating chain 1 of 2.
#> Estimating chain 2 of 2.
traceplot_K(mcmc)