This function creates trace plots for the K parameter in the form of a ggplot.
traceplot_K(mcmc)A ggplot of trace plots for the K parameter.
mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
#> [1] "Estimating chain 1 of 2."
#> [1] "Estimating chain 2 of 2."
traceplot_K(mcmc)