This function creates trace plots for the mu parameter in the form of a ggplot.

traceplot_mu(mcmc, names = NULL)

Arguments

mcmc

MCMC draws from the RaCE NMA model, in the form of the model output of the mcmc_RCMVN function.

names

A vector of intervention names (optional)

Value

A ggplot of trace plots for the mu parameter.

Examples

mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
#> [1] "Estimating chain 1 of 2."
#> [1] "Estimating chain 2 of 2."
traceplot_mu(mcmc,names=paste0("Treatment ",1:4))